@@ -96,7 +96,7 @@ def auto_create_folder_2(
     if platform.system( ).lower( ) == "windows":
         default_path = Path( driver_name + ":/" )
     elif platform.system( ).lower( ) == "darwin":
-        default_path = Path( default_driver )
+        default_path = Path( driver_name )
     else:
         pass
 
